@@ -3,7 +3,7 @@ use strict;
 local $^W = 1;
 BEGIN {
     use vars qw( $VERSION @ISA ); 
-    $VERSION = '0.43';
+    $VERSION = '0.44';
     use base qw(
         ExtUtils::ModuleMaker::Defaults
         ExtUtils::ModuleMaker::Initializers
@@ -11,15 +11,16 @@ BEGIN {
     );
 };
 use ExtUtils::ModuleMaker::Utility qw( 
-    _preexists_mmkr_directory
-    _make_mmkr_directory
     _get_dir_and_file
 );
 use Carp;
 use File::Path;
 use File::Spec;
-# use Data::Dumper;
 use Cwd;
+use File::Save::Home qw(
+    get_subhome_directory_status
+    make_subhome_directory
+);
 
 #################### PUBLICLY CALLABLE METHODS ####################
 
@@ -31,17 +32,29 @@ sub new {
 
     # multi-stage initialization of EU::MM object
     
-    # 1. Determine if there already exists on system a directory capable of
+    # 1.  Pull in arguments supplied to constructor -- but don't do anything
+    # with them yet.  These will come from one of three sources:
+    # a.  In a script:  KEY => 'Value' pairs supplied to new();
+    # b.  From modulemaker command-line:  -option 'Value' pairs following
+    # 'modulemaker';
+    # c.  From modulemaker interactive mode:  hard-wired values which may
+    # supersede (b) values.
+    my @arglist = @_;
+    croak "Must be hash or balanced list of key-value pairs: $!"
+        if (@arglist % 2);
+    my %supplied_params = @arglist;
+
+    # 2. Determine if there already exists on system a directory capable of
     # holding user ExtUtils::ModuleMaker::Personal::Defaults.  The name of
     # such a directory and whether it exists at THIS point are stored in an
     # array, a reference to which is the return value of
     # _preexists_mmkr_directory and which is then stored in the object.
     # NOTE:  If the directory does not yet exists, it is NOT automatically
     # created.
-    $self->{mmkr_dir_ref} =  _preexists_mmkr_directory();
+    $self->{mmkr_dir_ref} =  get_subhome_directory_status(".modulemaker");
     {
-        my $mmkr_dir = $self->{mmkr_dir_ref}->[0];
-        if (defined $self->{mmkr_dir_ref}->[1]) {
+        my $mmkr_dir = $self->{mmkr_dir_ref}->{abs};
+        if (defined $self->{mmkr_dir_ref}->{flag}) {
             push @INC, $mmkr_dir;
         }
         my $pers_file = File::Spec->catfile( $mmkr_dir,
@@ -53,32 +66,21 @@ sub new {
         }
     }
 
-    # 2.  Populate object with default values.  These values will come from
+    # 3.  Populate object with default values.  These values will come from
     # lib/ExtUtils/ModuleMaker/Defaults.pm, unless a Personal::Defaults file
     # has been located in step 1 above.
     my $defaults_ref;
     $defaults_ref = $self->default_values();
-    foreach my $def ( keys %{$defaults_ref} ) {
-        $self->{$def} = $defaults_ref->{$def};
+    foreach my $param ( keys %{$defaults_ref} ) {
+        $self->{$param} = $defaults_ref->{$param};
     }
     
-    # 3.  Pull in arguments supplied to constructor.
-    # These will come from one of three sources:
-    # a.  In a script, KEY => 'Value' pairs supplied to new();
-    # b.  From modulemaker command-line, -option 'Value' pairs following
-    # 'modulemaker';
-    # c.  From modulemaker interactive mode, hard-wired values which may
-    # supersede (b) values.
-    my @arglist = @_;
-    croak "Must be hash or balanced list of key-value pairs: $!"
-        if (@arglist % 2);
-    my %parameters = @arglist;
 
     # 4.  Process key-value pairs supplied as arguments to new() either
     # from user-written program or from modulemaker utility.
     # These override default values (or may provide additional elements).
-    foreach my $param ( keys %parameters ) {
-        $self->{$param} = $parameters{$param};
+    foreach my $param ( keys %supplied_params ) {
+        $self->{$param} = $supplied_params{$param};
     }
 
     # 5.  Initialize keys set from information supplied above, system
@@ -278,22 +280,29 @@ use strict;
 my %default_values = (
 END_TOPFILE
     
-my @keys_needed;
-for my $k (@dv) {
-    push @keys_needed, $k
-        unless (
-            $k eq 'ABSTRACT'         or 
-            $k eq 'SAVE_AS_DEFAULTS'
-        );
-}
-
-my $kvpairs;
-foreach my $k (@keys_needed) {
-    $kvpairs .=
-        (' ' x 8) . (sprintf '%-16s', $k) . '=> q{' . $selections{$k} .  "},\n";
-}
-$kvpairs .= (' ' x 8) . (sprintf '%-16s', 'ABSTRACT') . 
-    '=> q{Module abstract (<= 44 characters) goes here}' . "\n";
+    my @keys_needed;
+    for my $k (@dv) {
+        push @keys_needed, $k
+            unless (
+                $k eq 'ABSTRACT'         or 
+                $k eq 'SAVE_AS_DEFAULTS'
+            );
+    }
+    
+    my $kvpairs;
+    foreach my $k (@keys_needed) {
+        $kvpairs .=
+            (' ' x 8) . 
+            (sprintf '%-16s', $k) . 
+            '=> q{' . 
+            $selections{$k} .  
+            "},\n";
+    }
+    $kvpairs .= 
+        (' ' x 8) . 
+        (sprintf '%-16s', 'ABSTRACT') . 
+        '=> q{Module abstract (<= 44 characters) goes here}' . 
+        "\n";
 
     my $bottomfile = <<'END_BOTTOMFILE';
 );
@@ -309,7 +318,7 @@ END_BOTTOMFILE
 
     my $output =  $topfile . $kvpairs . $bottomfile;
 
-    my $mmkr_dir = _make_mmkr_directory($self->{mmkr_dir_ref});
+    my $mmkr_dir = make_subhome_directory($self->{mmkr_dir_ref});
     my $full_dir = File::Spec->catdir($mmkr_dir,
         qw| ExtUtils ModuleMaker Personal |
     );
@@ -371,8 +380,8 @@ Inside a Perl program:
 
 =head1 VERSION
 
-This document references version 0.43 of ExtUtils::ModuleMaker, released
-to CPAN on September 29, 2005.
+This document references version 0.44 of ExtUtils::ModuleMaker, released
+to CPAN on December 24, 2005.
 
 =head1 DESCRIPTION
 
@@ -1257,7 +1266,7 @@ org).
 
 Send email to jkeenan [at] cpan [dot] org.  Please include 'modulemaker'
 in the subject line.  Please report any bugs or feature requests to
-C<bug-ExtUtils-ModuleMaker\@rt.cpan.org>, or through the web interface at
+C<bug-ExtUtils-ModuleMaker@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 ACKNOWLEDGMENTS
@@ -1269,7 +1278,7 @@ Raton) and YAPC::EU::2003 (Paris).
 Soon after I took over maintenance of ExtUtils::ModuleMaker, David A
 Golden became a driving force in its ongoing development, providing
 suggestions for additional functionality as well as bug reports.  David is the
-author of ExtUtils::ModuleMaker::PBP which, while not a pure subclass of
+author of ExtUtils::ModuleMaker::TT which, while not a pure subclass of
 ExtUtils::ModuleMaker, extends its functionality for users of
 Template::Toolkit.
 
@@ -1334,3 +1343,4 @@ F<ExtUtils::ModuleMaker::PBP>, F<ExtUtils::ModuleMaker::TT>, F<mmkrpbp>.
 =cut
 
 
+
