@@ -1,9 +1,9 @@
 package ExtUtils::ModuleMaker::Opts;
-# as of 09-29-2005
+# as of 12-24-2005
 use strict;
 local $^W = 1;
 use vars qw( $VERSION );
-$VERSION = '0.43';
+$VERSION = '0.44';
 use Getopt::Std;
 use Carp;
 
@@ -40,9 +40,9 @@ sub new {
         ( ( $opts{v} ) ? ( VERSION               => $opts{v} ) : () ),
         ( ( $opts{l} ) ? ( LICENSE               => $opts{l} ) : () ),
         ( ( $opts{u} ) ? ( AUTHOR                => $opts{u} ) : () ),
-        ( ( $opts{p} ) ? ( CPANID                => $opts{p} ) : () ),
-        ( ( $opts{o} ) ? ( ORGANIZATION          => $opts{o} ) : () ),
-        ( ( $opts{w} ) ? ( WEBSITE               => $opts{w} ) : () ),
+        ( ( defined $opts{p} ) ? ( CPANID                => $opts{p} ) : () ),
+        ( ( defined $opts{o} ) ? ( ORGANIZATION          => $opts{o} ) : () ),
+        ( ( defined $opts{w} ) ? ( WEBSITE               => $opts{w} ) : () ),
         ( ( $opts{e} ) ? ( EMAIL                 => $opts{e} ) : () ),
         ( ( $opts{r} ) ? ( PERMISSIONS           => $opts{r} ) : () ),
         ( ( $opts{d} ) ? ( ALT_BUILD             => $opts{d} ) : () ),
