@@ -1,9 +1,9 @@
 package ExtUtils::ModuleMaker::StandardText;
-# as of 09-29-2005
+# as of 12-24-2005
 use strict;
 local $^W = 1;
 use vars qw ( $VERSION );
-$VERSION = '0.43';
+$VERSION = '0.44';
 use ExtUtils::ModuleMaker::Licenses::Standard qw(
     Get_Standard_License
     Verify_Standard_License
@@ -96,7 +96,7 @@ sub create_directory {
 
 =head3 C<print_file()>
 
-  Usage     : $self->print_file($filename, $filetext) within generate_pm_file()
+  Usage     : $self->print_file($filename, $filetext) within complete_build()
   Purpose   : Adds the file being created to MANIFEST, then prints text to new
               file.  Logs file creation under verbose.  Adds info for
               death_message in event of failure. 
@@ -553,7 +553,7 @@ END_OF_POD_TEST
 
 =head3 C<text_pm_file()>
 
-  Usage     : $self->text_pm_file($module) within generate_pm_file()
+  Usage     : $self->text_pm_file($module) within complete_build()
   Purpose   : Composes a string holding all elements for a pm file
   Returns   : String holding text for a pm file
   Argument  : $module: pointer to the module being built
@@ -1006,3 +1006,4 @@ F<ExtUtils::ModuleMaker>, F<ExtUtils::ModuleMaker::Initializers>.
 
 1;
 
+
